@@ -19,10 +19,37 @@ class Wms:
                                 'magatzem_entrada_id={magatzem_entrada_id}&finalitzades=false'
     _url_afegir_unitat_logistica_albara = '/wms/albarans/{albara_id}/expedicions'
     _url_borrar_unitat_logistica_albara = '/wms/albarans/{albara_id}/expedicions/{unitat_logistica_id}'
+    _url_tip_estats_unitats_logistiques = '/tip_estats_unitats_logistiques'
+    _url_tip_unitats_logistiques = '/tip_unitats_logistiques'
+    _url_tip_unitat_logistica_palet = '/tip_unitats_logistiques?palet=S'
+    _url_unitat_logistica_format = '/unitats_logistiques_formats?tip_unitat_logistica_id={tip_unitat_logistica_id}'
 
     def __init__(self, con: JManCon):
         self._con = con
 
+    def get_tip_estats_unitats_logistiques(self):
+        tmp_url = Wms._url_tip_estats_unitats_logistiques
+        res = self._con.get(url=tmp_url)
+        return res.json()
+
+    def get_tip_unitats_logistiques(self):
+        tmp_url = Wms._url_tip_unitats_logistiques
+        res = self._con.get(url=tmp_url)
+        return res.json()
+
+    def get_tip_unitat_logistica_palet(self):
+        tmp_url = Wms._url_tip_unitat_logistica_palet
+        llista = self._con.get(url=tmp_url)
+        res = None
+        if (llista is not None) and (len(llista) > 0):
+            res = llista[0]
+        return res.json()
+
+    def get_unitats_logistiques_formats(self, p_tip_unitat_logistica_id: int):
+        tmp_url = Wms._url_unitat_logistica_format.format(tip_unitat_logistica_id=p_tip_unitat_logistica_id)
+        res = self._con.get(url=tmp_url)
+        return res.json()
+
     def get_estoc(self, p_article_atribut_id: int, p_article_lot_id: int = None):
         tmp_url = Wms._url_estoc.format(art_atrib_id=p_article_atribut_id)
         if p_article_lot_id is not None:
