@@ -96,15 +96,16 @@ class JManCon:
         if data is not None:
             data = json.dumps(data)
         try:
+            req = None
             req = requests.post(url=self._config.url() + url, headers=headers, data=data)
         except requests.exceptions.RequestException:
-            raise JManErrorConnection()
+            raise JManErrorConnection(req.content)
         if req.status_code < 200 or 300 <= req.status_code < 400:
-            raise JManErrorConnection()
+            raise JManErrorConnection(req.content)
         if req.status_code < 200 or req.status_code >= 500:
-            raise JManErrorApp()
+            raise JManErrorApp(req.content)
         if 400 <= req.status_code < 500:
-            raise JManErrorClient()
+            raise JManErrorClient(req.content)
         return req
 
     def put(self, url: str, data: [list, dict, None]) -> requests:
@@ -117,15 +118,16 @@ class JManCon:
         if data is not None:
             data = json.dumps(data)
         try:
+            req = None
             req = requests.put(url=self._config.url() + url, headers=headers, data=data)
         except requests.exceptions.RequestException:
-            raise JManErrorConnection()
+            raise JManErrorConnection(req.content)
         if req.status_code < 200 or 300 <= req.status_code < 400:
-            raise JManErrorConnection()
+            raise JManErrorConnection(req.content)
         if req.status_code < 200 or req.status_code >= 500:
-            raise JManErrorApp()
+            raise JManErrorApp(req.content)
         if 400 <= req.status_code < 500:
-            raise JManErrorClient()
+            raise JManErrorClient(req.content)
         return req
 
     def get(self, url: str) -> requests:
@@ -134,29 +136,31 @@ class JManCon:
             'authorization': "Bearer " + self.usuari_token
         }
         try:
+            req = None
             req = requests.get(url=self._config.url() + url, headers=headers)
         except requests.exceptions.RequestException:
-            raise JManErrorConnection()
+            raise JManErrorConnection(req.content)
         if req.status_code < 200 or 300 <= req.status_code < 400:
-            raise JManErrorConnection()
+            raise JManErrorConnection(req.content)
         if req.status_code < 200 or req.status_code >= 500:
-            raise JManErrorApp()
+            raise JManErrorApp(req.content)
         if 400 <= req.status_code < 500:
-            raise JManErrorClient()
+            raise JManErrorClient(req.content)
         return req
 
     def delete(self, url: str) -> requests:
         headers = {'authorization': "Bearer " + self.usuari_token}
         try:
+            req = None
             req = requests.delete(url=self._config.url() + url, headers=headers)
         except requests.exceptions.RequestException:
-            raise JManErrorConnection()
+            raise JManErrorConnection(req.content)
         if req.status_code < 200 or 300 <= req.status_code < 400:
-            raise JManErrorConnection()
+            raise JManErrorConnection(req.content)
         if req.status_code < 200 or req.status_code >= 500:
-            raise JManErrorApp()
+            raise JManErrorApp(req.content)
         if 400 <= req.status_code < 500:
-            raise JManErrorClient()
+            raise JManErrorClient(req.content)
         return req
 
     def __del__(self):
